[tablet] updated op-related messages

This patch does not contain any functional changes.

This is a follow-up to e4c2cb91020d67a97195e0b7745cc2a98562e4c4.

Change-Id: I0ee3cc9e4b88e14bf65fc5486edc0694a1046b28
Reviewed-on: http://gerrit.cloudera.org:8080/16479
Tested-by: Kudu Jenkins
Reviewed-by: Grant Henke <granthenke@apache.org>
diff --git a/src/kudu/tablet/mvcc.h b/src/kudu/tablet/mvcc.h
index 32d205b..65ab642 100644
--- a/src/kudu/tablet/mvcc.h
+++ b/src/kudu/tablet/mvcc.h
@@ -339,7 +339,7 @@
   // been achieved.
   bool IsDoneWaitingUnlocked(const WaitingState& waiter) const;
 
-  // Commits the given op.
+  // Applies the given op.
   // Sets *was_earliest to true if this was the earliest in-flight op.
   void ApplyOpUnlocked(Timestamp timestamp,
                         bool* was_earliest_in_flight);
@@ -400,7 +400,7 @@
   // When this op is applied it will use MvccManager::FinishApplyingOp().
   ScopedOp(MvccManager* manager, Timestamp timestamp);
 
-  // Commit the op referenced by this scoped object, if it hasn't
+  // Finish applying the op referenced by this scoped object, if it hasn't
   // already been applied.
   ~ScopedOp();
 
@@ -415,7 +415,7 @@
   // method.
   void StartApplying();
 
-  // Commit the in-flight op.
+  // Finish applying the in-flight op.
   //
   // Requires that StartApplying() has been called.
   void FinishApplying();
diff --git a/src/kudu/tablet/tablet_replica.cc b/src/kudu/tablet/tablet_replica.cc
index cfad381..682d9e8 100644
--- a/src/kudu/tablet/tablet_replica.cc
+++ b/src/kudu/tablet/tablet_replica.cc
@@ -955,13 +955,13 @@
   // This ensures that the above-mentioned commit messages are not just enqueued
   // to the log, but also on disk.
   VLOG(1) << "T " << tablet_->metadata()->tablet_id()
-      <<  ": Waiting for in-flight ops to commit.";
-  LOG_SLOW_EXECUTION(WARNING, 200, "Committing in-flights took a long time.") {
+      <<  ": waiting for in-flight ops to apply";
+  LOG_SLOW_EXECUTION(WARNING, 200, "applying in-flights took a long time") {
     RETURN_NOT_OK(tablet_->mvcc_manager()->WaitForApplyingOpsToApply());
   }
   VLOG(1) << "T " << tablet_->metadata()->tablet_id()
-      << ": Waiting for the log queue to be flushed.";
-  LOG_SLOW_EXECUTION(WARNING, 200, "Flushing the Log queue took a long time.") {
+      << ": waiting for the log queue to be flushed";
+  LOG_SLOW_EXECUTION(WARNING, 200, "flushing the Log queue took a long time") {
     RETURN_NOT_OK(log_->WaitUntilAllFlushed());
   }
   return Status::OK();
diff --git a/src/kudu/tablet/mvcc.cc b/src/kudu/tablet/mvcc.cc
index 8f58329..cca1054 100644
--- a/src/kudu/tablet/mvcc.cc
+++ b/src/kudu/tablet/mvcc.cc
@@ -136,7 +136,7 @@
 void MvccManager::FinishApplyingOp(Timestamp timestamp) {
   std::lock_guard<LockType> l(lock_);
 
   // Commit the op, but do not adjust 'all_applied_before_', that will
   // be done with a separate OfflineAdjustCurSnap() call.
   bool was_earliest = false;
   ApplyOpUnlocked(timestamp, &was_earliest);
@@ -144,7 +144,6 @@
   // NOTE: we should have pushed the lower bound forward before applying, but
   // we may not have in tests.
   if (was_earliest && new_op_timestamp_exc_lower_bound_ >= timestamp) {
-
     // If this op was the earliest in-flight, we might have to adjust
     // the "clean" timestamp.
     AdjustCleanTimeUnlocked();
@@ -386,7 +385,7 @@
 }
 
 Status MvccManager::WaitForApplyingOpsToApply() const {
-  TRACE_EVENT0("tablet", "MvccManager::WaitForApplyingOpsToCommit");
+  TRACE_EVENT0("tablet", "MvccManager::WaitForApplyingOpsToApply");
   RETURN_NOT_OK(CheckOpen());
 
   // Find the highest timestamp of an APPLYING op.
@@ -136,7 +136,7 @@
   std::lock_guard<LockType> l(lock_);
 
-  // Commit the op, but do not adjust 'all_applied_before_', that will
+  // Apply the op, but do not adjust 'all_applied_before_', that will
   // be done with a separate OfflineAdjustCurSnap() call.
   bool was_earliest = false;